1

Здравствуйте. Искал в интернете приоритетные драйвера на amd, чтобы заработал compiz - скачал с офф сайта amd. Установил .run файл через терминал, после установки изменилось всё в худшею сторону! ПОСЛЕ перезагрузки Gnome выдал сообщения, что якобы извини Вася, твои дрова не поддерживаются. Далее у меня стала тема оформления gnome старая и стала вылезает ошибка, чуть ли ни каждый раз после запуска программ.
ПОМОГиТЕ...

2

3.2.8. Запрещено использовать методы ввода текста, усложняющие его восприятие:

    использовать транслит в названиях тем и сообщениях;
    заменять русские буквы похожими буквами латинского алфавита или цифрами;
    создавать темы и сообщения ПРОПИСНЫМИ БУКВАМИ;
    создавать сообщения прописными и строчными буквами или буквами разных алфавитов вперемешку;
    вносить намеренные ошибки или намеренно не соблюдать правила русского языка;
    использовать в темах и сообщениях символы псевдографики;
    визуально выделять каким-то образом всё сообщение целиком;
    цитировать сообщения нестандартным способом, т.е. без использования стандартных кодов.

Был, был и весь вышел...

3

mr_zedox пишет:

приоритетные драйвера на amd

1. Проприетарные, вы хотели сказать.
2. Покажите:
2а) информацию о железе (выполнять от рута):

# lspci -k | grep -i video

2б). Информацию о драйвере: какой версии, откуда взят, какие ошибки вылезают после перезагрузки - показывайте сообщения Gnome и

$ cat /var/log/Xorg.0.log

а также какой драйвер до этого стоял (если возможно)
2в). На всякий случай, информацию о загруженных модулях ядра:

# lsmod
Истинный hotplug - это обычная электрическая розетка: воткнул - работает, и никаких драйверов.
Arch Linux/Xfce/Xiaomi Mi Notebook Pro 15.6 | Slackware64-current/Xfce/Lenovo G580

4

2a) Ничего не выводит, просто команда проходит и всё.
2б) Результат выполнения в командой строке: cat /var/log/Xorg.0.log:

    ATI Mobility Radeon HD 3850 X2, ATI RV670,
    ATI Mobility Radeon HD 3870, ATI Mobility Radeon HD 3870 X2,
    ATI Radeon HD3870 X2, ATI FireGL V7700, ATI Radeon HD3850,
    ATI Radeon HD3690, AMD Firestream 9170, ATI Radeon HD 4550,
    ATI Radeon RV710, ATI Radeon RV710, ATI Radeon RV710,
    ATI Radeon HD 4350, ATI Mobility Radeon 4300 Series,
    ATI Mobility Radeon 4500 Series, ATI Mobility Radeon 4500 Series,
    ATI FirePro RG220, ATI Mobility Radeon 4330, ATI RV630,
    ATI Mobility Radeon HD 2600, ATI Mobility Radeon HD 2600 XT,
    ATI Radeon HD 2600 XT AGP, ATI Radeon HD 2600 Pro AGP,
    ATI Radeon HD 2600 XT, ATI Radeon HD 2600 Pro, ATI Gemini RV630,
    ATI Gemini Mobility Radeon HD 2600 XT, ATI FireGL V5600,
    ATI FireGL V3600, ATI Radeon HD 2600 LE,
    ATI Mobility FireGL Graphics Processor, ATI Radeon HD 3470,
    ATI Mobility Radeon HD 3430, ATI Mobility Radeon HD 3400 Series,
    ATI Radeon HD 3450, ATI Radeon HD 3450, ATI Radeon HD 3430,
    ATI Radeon HD 3450, ATI FirePro V3700, ATI FireMV 2450,
    ATI FireMV 2260, ATI FireMV 2260, ATI Radeon HD 3600 Series,
    ATI Radeon HD 3650 AGP, ATI Radeon HD 3600 PRO,
    ATI Radeon HD 3600 XT, ATI Radeon HD 3600 PRO,
    ATI Mobility Radeon HD 3650, ATI Mobility Radeon HD 3670,
    ATI Mobility FireGL V5700, ATI Mobility FireGL V5725,
    ATI Radeon HD 3200 Graphics, ATI Radeon 3100 Graphics,
    ATI Radeon HD 3200 Graphics, ATI Radeon 3100 Graphics,
    ATI Radeon HD 3300 Graphics, ATI Radeon HD 3200 Graphics,
    ATI Radeon 3000 Graphics, SUMO, SUMO, SUMO2, SUMO2, SUMO2, SUMO2,
    SUMO, SUMO, SUMO, SUMO, SUMO, SUMO, SUMO, ATI Radeon HD 4200,
    ATI Radeon 4100, ATI Mobility Radeon HD 4200,
    ATI Mobility Radeon 4100, ATI Radeon HD 4290, ATI Radeon HD 4250,
    AMD Radeon HD 6310 Graphics, AMD Radeon HD 6310 Graphics,
    AMD Radeon HD 6250 Graphics, AMD Radeon HD 6250 Graphics,
    AMD Radeon HD 6300 Series Graphics,
    AMD Radeon HD 6200 Series Graphics, PALM, PALM, CYPRESS,
    ATI FirePro (FireGL) Graphics Adapter,
    ATI FirePro (FireGL) Graphics Adapter,
    ATI FirePro (FireGL) Graphics Adapter, AMD Firestream 9370,
    AMD Firestream 9350, ATI Radeon HD 5800 Series,
    ATI Radeon HD 5800 Series, ATI Radeon HD 5800 Series,
    ATI Radeon HD 5800 Series, ATI Radeon HD 5900 Series,
    ATI Radeon HD 5900 Series, ATI Mobility Radeon HD 5800 Series,
    ATI Mobility Radeon HD 5800 Series,
    ATI FirePro (FireGL) Graphics Adapter,
    ATI FirePro (FireGL) Graphics Adapter,
    ATI Mobility Radeon HD 5800 Series, ATI Radeon HD 5700 Series,
    ATI Radeon HD 5700 Series, ATI Radeon HD 6700 Series,
    ATI Radeon HD 5700 Series, ATI Radeon HD 6700 Series,
    ATI Mobility Radeon HD 5000 Series,
    ATI Mobility Radeon HD 5000 Series, ATI Mobility Radeon HD 5570,
    ATI FirePro (FireGL) Graphics Adapter,
    ATI FirePro (FireGL) Graphics Adapter, ATI Radeon HD 5670,
    ATI Radeon HD 5570, ATI Radeon HD 5500 Series, REDWOOD,
    ATI Mobility Radeon HD 5000 Series,
    ATI Mobility Radeon HD 5000 Series, ATI Mobility Radeon Graphics,
    ATI Mobility Radeon Graphics, CEDAR,
    ATI FirePro (FireGL) Graphics Adapter,
    ATI FirePro (FireGL) Graphics Adapter, ATI FirePro 2270, CEDAR,
    ATI Radeon HD 5450, CEDAR, CEDAR, CAYMAN, CAYMAN, CAYMAN, CAYMAN,
    CAYMAN, CAYMAN, CAYMAN, CAYMAN, CAYMAN, CAYMAN,
    AMD Radeon HD 6900 Series, AMD Radeon HD 6900 Series, CAYMAN, CAYMAN,
    CAYMAN, AMD Radeon HD 6900M Series, Mobility Radeon HD 6000 Series,
    BARTS, BARTS, Mobility Radeon HD 6000 Series,
    Mobility Radeon HD 6000 Series, BARTS, BARTS, BARTS, BARTS,
    AMD Radeon HD 6800 Series, AMD Radeon HD 6800 Series,
    AMD Radeon HD 6700 Series, TURKS, TURKS, TURKS, TURKS, TURKS, TURKS,
    TURKS, TURKS, TURKS, TURKS, TURKS, TURKS, TURKS, TURKS, TURKS, TURKS,
    TURKS, TURKS, TURKS, TURKS, TURKS, TURKS, TURKS, TURKS, TURKS,
    CAICOS, CAICOS, CAICOS, CAICOS, CAICOS, CAICOS, CAICOS, CAICOS,
    CAICOS, CAICOS, CAICOS, CAICOS, CAICOS, CAICOS
[    41.159] (II) VESA: driver for VESA chipsets: vesa
[    41.159] (II) FBDEV: driver for framebuffer: fbdev
[    41.159] (++) using VT number 1

[    41.160] (II) Loading /usr/lib/xorg/modules/drivers/radeon_drv.so
[    41.160] (II) [KMS] Kernel modesetting enabled.
[    41.160] (WW) Falling back to old probe method for vesa
[    41.160] (WW) Falling back to old probe method for fbdev
[    41.160] (II) Loading sub module "fbdevhw"
[    41.160] (II) LoadModule: "fbdevhw"
[    41.161] (II) Loading /usr/lib/xorg/modules/libfbdevhw.so
[    41.161] (II) Module fbdevhw: vendor="X.Org Foundation"
[    41.161]     compiled for 1.11.4, module version = 0.0.2
[    41.161]     ABI class: X.Org Video Driver, version 11.0
[    41.161] (II) RADEON(0): Creating default Display subsection in Screen section
    "Default Screen Section" for depth/fbbpp 24/32
[    41.161] (==) RADEON(0): Depth 24, (--) framebuffer bpp 32
[    41.161] (II) RADEON(0): Pixel depth = 24 bits stored in 4 bytes (32 bpp pixmaps)
[    41.161] (==) RADEON(0): Default visual is TrueColor
[    41.161] (==) RADEON(0): RGB weight 888
[    41.161] (II) RADEON(0): Using 8 bits per RGB (8 bit DAC)
[    41.161] (--) RADEON(0): Chipset: "ATI Mobility Radeon HD 5000 Series" (ChipID = 0x68e0)
[    41.161] (II) RADEON(0): PCIE card detected
[    41.161] drmOpenDevice: node name is /dev/dri/card0
[    41.161] drmOpenDevice: open result is 8, (OK)
[    41.161] drmOpenByBusid: Searching for BusID pci:0000:01:00.0
[    41.161] drmOpenDevice: node name is /dev/dri/card0
[    41.161] drmOpenDevice: open result is 8, (OK)
[    41.161] drmOpenByBusid: drmOpenMinor returns 8
[    41.161] drmOpenByBusid: drmGetBusid reports pci:0000:01:00.0
[    41.161] (II) Loading sub module "exa"
[    41.161] (II) LoadModule: "exa"
[    41.162] (II) Loading /usr/lib/xorg/modules/libexa.so
[    41.162] (II) Module exa: vendor="X.Org Foundation"
[    41.162]     compiled for 1.11.4, module version = 2.5.0
[    41.162]     ABI class: X.Org Video Driver, version 11.0
[    41.162] (II) RADEON(0): KMS Color Tiling: enabled
[    41.162] (II) RADEON(0): KMS Pageflipping: enabled
[    41.162] (II) RADEON(0): SwapBuffers wait for vsync: enabled
[    41.162] (II) RADEON(0): Output LVDS has no monitor section
[    41.167] (II) RADEON(0): Output HDMI-0 has no monitor section
[    41.183] (II) RADEON(0): Output VGA-0 has no monitor section
[    41.183] (II) RADEON(0): EDID for output LVDS
[    41.183] (II) RADEON(0): Manufacturer: SEC  Model: 3245  Serial#: 0
[    41.183] (II) RADEON(0): Year: 2010  Week: 0
[    41.183] (II) RADEON(0): EDID Version: 1.3
[    41.183] (II) RADEON(0): Digital Display Input
[    41.183] (II) RADEON(0): Max Image Size [cm]: horiz.: 34  vert.: 19
[    41.183] (II) RADEON(0): Gamma: 2.20
[    41.183] (II) RADEON(0): No DPMS capabilities specified
[    41.183] (II) RADEON(0): Supported color encodings: RGB 4:4:4 YCrCb 4:4:4 
[    41.183] (II) RADEON(0): First detailed timing is preferred mode
[    41.183] (II) RADEON(0): redX: 0.580 redY: 0.340   greenX: 0.310 greenY: 0.550
[    41.183] (II) RADEON(0): blueX: 0.155 blueY: 0.155   whiteX: 0.313 whiteY: 0.329
[    41.183] (II) RADEON(0): Manufacturer's mask: 0
[    41.183] (II) RADEON(0): Supported detailed timing:
[    41.183] (II) RADEON(0): clock: 70.4 MHz   Image Size:  344 x 194 mm
[    41.183] (II) RADEON(0): h_active: 1366  h_sync: 1414  h_sync_end 1446 h_blank_end 1486 h_border: 0
[    41.183] (II) RADEON(0): v_active: 768  v_sync: 770  v_sync_end 775 v_blanking: 790 v_border: 0
[    41.183] (II) RADEON(0): Unknown vendor-specific block f
[    41.183] (II) RADEON(0):  SAMSUNG
[    41.183] (II) RADEON(0):  LTN156AT02000
[    41.183] (II) RADEON(0): EDID (in hex):
[    41.183] (II) RADEON(0):     00ffffffffffff004ca3453200000000
[    41.183] (II) RADEON(0):     00140103802213780a87f594574f8c27
[    41.183] (II) RADEON(0):     27505400000001010101010101010101
[    41.183] (II) RADEON(0):     010101010101841b5678500016303020
[    41.183] (II) RADEON(0):     250058c2100000190000000f00000000
[    41.183] (II) RADEON(0):     00000000002387026401000000fe0053
[    41.183] (II) RADEON(0):     414d53554e470a2020202020000000fe
[    41.183] (II) RADEON(0):     004c544e31353641543032303030005d
[    41.183] (II) RADEON(0): EDID vendor "SEC", prod id 12869
[    41.183] (II) RADEON(0): Printing DDC gathered Modelines:
[    41.183] (II) RADEON(0): Modeline "1366x768"x0.0   70.44  1366 1414 1446 1486  768 770 775 790 -hsync -vsync (47.4 kHz)
[    41.184] (II) RADEON(0): Printing probed modes for output LVDS
[    41.184] (II) RADEON(0): Modeline "1366x768"x60.0   70.44  1366 1414 1446 1486  768 770 775 790 -hsync -vsync (47.4 kHz)
[    41.184] (II) RADEON(0): Modeline "1280x720"x59.9   74.50  1280 1344 1472 1664  720 723 728 748 -hsync +vsync (44.8 kHz)
[    41.184] (II) RADEON(0): Modeline "1152x768"x59.8   71.75  1152 1216 1328 1504  768 771 781 798 -hsync +vsync (47.7 kHz)
[    41.184] (II) RADEON(0): Modeline "1024x768"x120.1  133.47  1024 1100 1212 1400  768 768 770 794 doublescan -hsync +vsync (95.3 kHz)
[    41.184] (II) RADEON(0): Modeline "1024x768"x60.0   65.00  1024 1048 1184 1344  768 771 777 806 -hsync -vsync (48.4 kHz)
[    41.184] (II) RADEON(0): Modeline "1024x768"x59.9   63.50  1024 1072 1176 1328  768 771 775 798 -hsync +vsync (47.8 kHz)
[    41.184] (II) RADEON(0): Modeline "960x720"x120.0  117.00  960 1024 1128 1300  720 720 722 750 doublescan -hsync +vsync (90.0 kHz)
[    41.184] (II) RADEON(0): Modeline "928x696"x120.1  109.15  928 976 1088 1264  696 696 698 719 doublescan -hsync +vsync (86.4 kHz)
[    41.184] (II) RADEON(0): Modeline "896x672"x120.0  102.40  896 960 1060 1224  672 672 674 697 doublescan -hsync +vsync (83.7 kHz)
[    41.184] (II) RADEON(0): Modeline "800x600"x120.0   81.00  800 832 928 1080  600 600 602 625 doublescan +hsync +vsync (75.0 kHz)
[    41.184] (II) RADEON(0): Modeline "800x600"x60.3   40.00  800 840 968 1056  600 601 605 628 +hsync +vsync (37.9 kHz)
[    41.184] (II) RADEON(0): Modeline "800x600"x59.9   38.25  800 832 912 1024  600 603 607 624 -hsync +vsync (37.4 kHz)
[    41.184] (II) RADEON(0): Modeline "800x600"x56.2   36.00  800 824 896 1024  600 601 603 625 +hsync +vsync (35.2 kHz)
[    41.184] (II) RADEON(0): Modeline "848x480"x59.7   31.50  848 872 952 1056  480 483 493 500 -hsync +vsync (29.8 kHz)
[    41.184] (II) RADEON(0): Modeline "700x525"x120.0   61.00  700 744 820 940  525 526 532 541 doublescan +hsync +vsync (64.9 kHz)
[    41.184] (II) RADEON(0): Modeline "720x480"x59.7   26.75  720 744 808 896  480 483 493 500 -hsync +vsync (29.9 kHz)
[    41.184] (II) RADEON(0): Modeline "640x512"x120.0   54.00  640 664 720 844  512 512 514 533 doublescan +hsync +vsync (64.0 kHz)
[    41.184] (II) RADEON(0): Modeline "640x480"x120.0   54.00  640 688 744 900  480 480 482 500 doublescan +hsync +vsync (60.0 kHz)
[    41.184] (II) RADEON(0): Modeline "640x480"x59.9   25.18  640 656 752 800  480 490 492 525 -hsync -vsync (31.5 kHz)
[    41.184] (II) RADEON(0): Modeline "640x480"x59.4   23.75  640 664 720 800  480 483 487 500 -hsync +vsync (29.7 kHz)
[    41.184] (II) RADEON(0): Modeline "512x384"x120.0   32.50  512 524 592 672  384 385 388 403 doublescan -hsync -vsync (48.4 kHz)
[    41.184] (II) RADEON(0): Modeline "400x300"x120.6   20.00  400 420 484 528  300 300 302 314 doublescan +hsync +vsync (37.9 kHz)
[    41.184] (II) RADEON(0): Modeline "400x300"x112.7   18.00  400 412 448 512  300 300 301 312 doublescan +hsync +vsync (35.2 kHz)
[    41.184] (II) RADEON(0): Modeline "320x240"x120.1   12.59  320 328 376 400  240 245 246 262 doublescan -hsync -vsync (31.5 kHz)
[    41.189] (II) RADEON(0): EDID for output HDMI-0
[    41.205] (II) RADEON(0): EDID for output VGA-0
[    41.205] (II) RADEON(0): Output LVDS connected
[    41.205] (II) RADEON(0): Output HDMI-0 disconnected
[    41.205] (II) RADEON(0): Output VGA-0 disconnected
[    41.205] (II) RADEON(0): Using exact sizes for initial modes
[    41.205] (II) RADEON(0): Output LVDS using initial mode 1366x768 +0+0
[    41.205] (II) RADEON(0): Using default gamma of (1.0, 1.0, 1.0) unless otherwise stated.
[    41.205] (II) RADEON(0): mem size init: gart size :1fdff000 vram size: s:20000000 visible:fba0000
[    41.205] (II) RADEON(0): EXA: Driver will allow EXA pixmaps in VRAM
[    41.205] (**) RADEON(0): Display dimensions: (340, 190) mm
[    41.205] (**) RADEON(0): DPI set to (102, 102)
[    41.205] (II) Loading sub module "fb"
[    41.205] (II) LoadModule: "fb"
[    41.205] (II) Loading /usr/lib/xorg/modules/libfb.so
[    41.206] (II) Module fb: vendor="X.Org Foundation"
[    41.206]     compiled for 1.11.4, module version = 1.0.0
[    41.206]     ABI class: X.Org ANSI C Emulation, version 0.4
[    41.206] (II) Loading sub module "ramdac"
[    41.206] (II) LoadModule: "ramdac"
[    41.206] (II) Module "ramdac" already built-in
[    41.206] (II) UnloadModule: "vesa"
[    41.206] (II) Unloading vesa
[    41.206] (II) UnloadModule: "fbdev"
[    41.206] (II) Unloading fbdev
[    41.206] (II) UnloadModule: "fbdevhw"
[    41.206] (II) Unloading fbdevhw
[    41.206] (--) Depth 24 pixmap format is 32 bpp
[    41.206] (II) RADEON(0): [DRI2] Setup complete
[    41.206] (II) RADEON(0): [DRI2]   DRI driver: r600
[    41.206] (II) RADEON(0): [DRI2]   VDPAU driver: r600
[    41.206] (II) RADEON(0): Front buffer size: 4224K
[    41.206] (II) RADEON(0): VRAM usage limit set to 228096K
[    41.206] (==) RADEON(0): Backing store disabled
[    41.206] (II) RADEON(0): Direct rendering enabled
[    41.206] (II) RADEON(0): Setting EXA maxPitchBytes
[    41.206] (II) EXA(0): Driver allocated offscreen pixmaps
[    41.206] (II) EXA(0): Driver registered support for the following operations:
[    41.206] (II)         Solid
[    41.206] (II)         Copy
[    41.206] (II)         Composite (RENDER acceleration)
[    41.206] (II)         UploadToScreen
[    41.206] (II)         DownloadFromScreen
[    41.206] (II) RADEON(0): Acceleration enabled
[    41.206] (==) RADEON(0): DPMS enabled
[    41.206] (==) RADEON(0): Silken mouse enabled
[    41.206] (II) RADEON(0): Set up textured video
[    41.206] (II) RADEON(0): [XvMC] Associated with Radeon Textured Video.
[    41.206] (II) RADEON(0): [XvMC] Extension initialized.
[    41.206] (II) RADEON(0): RandR 1.2 enabled, ignore the following RandR disabled message.
[    41.207] (--) RandR disabled
[    41.207] (II) Initializing built-in extension Generic Event Extension
[    41.207] (II) Initializing built-in extension SHAPE
[    41.207] (II) Initializing built-in extension MIT-SHM
[    41.207] (II) Initializing built-in extension XInputExtension
[    41.207] (II) Initializing built-in extension XTEST
[    41.207] (II) Initializing built-in extension BIG-REQUESTS
[    41.207] (II) Initializing built-in extension SYNC
[    41.207] (II) Initializing built-in extension XKEYBOARD
[    41.207] (II) Initializing built-in extension XC-MISC
[    41.207] (II) Initializing built-in extension XINERAMA
[    41.207] (II) Initializing built-in extension XFIXES
[    41.207] (II) Initializing built-in extension RENDER
[    41.207] (II) Initializing built-in extension RANDR
[    41.207] (II) Initializing built-in extension COMPOSITE
[    41.207] (II) Initializing built-in extension DAMAGE
[    41.208] (II) SELinux: Disabled by boolean
[    41.211] (EE) GLX error: Can not get required symbols.
[    41.218] (II) RADEON(0): Setting screen physical size to 361 x 203
[    41.324] (II) config/udev: Adding input device Power Button (/dev/input/event3)
[    41.324] (**) Power Button: Applying InputClass "evdev keyboard catchall"
[    41.324] (**) Power Button: Applying InputClass "system-setup-keyboard"
[    41.324] (II) LoadModule: "evdev"
[    41.324] (II) Loading /usr/lib/xorg/modules/input/evdev_drv.so
[    41.324] (II) Module evdev: vendor="X.Org Foundation"
[    41.324]     compiled for 1.11.3, module version = 2.6.99
[    41.324]     Module class: X.Org XInput Driver
[    41.324]     ABI class: X.Org XInput driver, version 13.0
[    41.324] (II) Using input driver 'evdev' for 'Power Button'
[    41.324] (II) Loading /usr/lib/xorg/modules/input/evdev_drv.so
[    41.324] (**) Power Button: always reports core events
[    41.324] (**) evdev: Power Button: Device: "/dev/input/event3"
[    41.324] (--) evdev: Power Button: Vendor 0 Product 0x1
[    41.324] (--) evdev: Power Button: Found keys
[    41.324] (II) evdev: Power Button: Configuring as keyboard
[    41.324] (**) Option "config_info" "udev:/sys/devices/LNXSYSTM:00/LNXPWRBN:00/input/input3/event3"
[    41.324] (II) XINPUT: Adding extended input device "Power Button" (type: KEYBOARD, id 6)
[    41.324] (**) Option "xkb_rules" "evdev"
[    41.324] (**) Option "xkb_model" "pc105+inet"
[    41.324] (**) Option "xkb_layout" "us"
[    41.324] (**) Option "xkb_options" "terminate:ctrl_alt_bksp,"
[    41.350] (II) config/udev: Adding input device Video Bus (/dev/input/event6)
[    41.350] (**) Video Bus: Applying InputClass "evdev keyboard catchall"
[    41.350] (**) Video Bus: Applying InputClass "system-setup-keyboard"
[    41.350] (II) Using input driver 'evdev' for 'Video Bus'
[    41.350] (II) Loading /usr/lib/xorg/modules/input/evdev_drv.so
[    41.351] (**) Video Bus: always reports core events
[    41.351] (**) evdev: Video Bus: Device: "/dev/input/event6"
[    41.351] (--) evdev: Video Bus: Vendor 0 Product 0x6
[    41.351] (--) evdev: Video Bus: Found keys
[    41.351] (II) evdev: Video Bus: Configuring as keyboard
[    41.351] (**) Option "config_info" "udev:/sys/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/LNXVIDEO:00/input/input6/event6"
[    41.351] (II) XINPUT: Adding extended input device "Video Bus" (type: KEYBOARD, id 7)
[    41.351] (**) Option "xkb_rules" "evdev"
[    41.351] (**) Option "xkb_model" "pc105+inet"
[    41.351] (**) Option "xkb_layout" "us"
[    41.351] (**) Option "xkb_options" "terminate:ctrl_alt_bksp,"
[    41.351] (II) config/udev: Adding input device Power Button (/dev/input/event0)
[    41.351] (**) Power Button: Applying InputClass "evdev keyboard catchall"
[    41.351] (**) Power Button: Applying InputClass "system-setup-keyboard"
[    41.351] (II) Using input driver 'evdev' for 'Power Button'
[    41.351] (II) Loading /usr/lib/xorg/modules/input/evdev_drv.so
[    41.351] (**) Power Button: always reports core events
[    41.351] (**) evdev: Power Button: Device: "/dev/input/event0"
[    41.351] (--) evdev: Power Button: Vendor 0 Product 0x1
[    41.351] (--) evdev: Power Button: Found keys
[    41.351] (II) evdev: Power Button: Configuring as keyboard
[    41.351] (**) Option "config_info" "udev:/sys/devices/LNXSYSTM:00/device:00/PNP0C0C:00/input/input0/event0"
[    41.351] (II) XINPUT: Adding extended input device "Power Button" (type: KEYBOARD, id 8)
[    41.351] (**) Option "xkb_rules" "evdev"
[    41.351] (**) Option "xkb_model" "pc105+inet"
[    41.351] (**) Option "xkb_layout" "us"
[    41.351] (**) Option "xkb_options" "terminate:ctrl_alt_bksp,"
[    41.352] (II) config/udev: Adding input device Lid Switch (/dev/input/event2)
[    41.352] (II) No input driver specified, ignoring this device.
[    41.352] (II) This device may have been added with another device file.
[    41.352] (II) config/udev: Adding input device Sleep Button (/dev/input/event1)
[    41.352] (**) Sleep Button: Applying InputClass "evdev keyboard catchall"
[    41.352] (**) Sleep Button: Applying InputClass "system-setup-keyboard"
[    41.352] (II) Using input driver 'evdev' for 'Sleep Button'
[    41.352] (II) Loading /usr/lib/xorg/modules/input/evdev_drv.so
[    41.352] (**) Sleep Button: always reports core events
[    41.352] (**) evdev: Sleep Button: Device: "/dev/input/event1"
[    41.352] (--) evdev: Sleep Button: Vendor 0 Product 0x3
[    41.352] (--) evdev: Sleep Button: Found keys
[    41.352] (II) evdev: Sleep Button: Configuring as keyboard
[    41.352] (**) Option "config_info" "udev:/sys/devices/LNXSYSTM:00/device:00/PNP0C0E:00/input/input1/event1"
[    41.352] (II) XINPUT: Adding extended input device "Sleep Button" (type: KEYBOARD, id 9)
[    41.352] (**) Option "xkb_rules" "evdev"
[    41.352] (**) Option "xkb_model" "pc105+inet"
[    41.352] (**) Option "xkb_layout" "us"
[    41.352] (**) Option "xkb_options" "terminate:ctrl_alt_bksp,"
[    41.353] (II) config/udev: Adding input device HD-Audio Generic HDMI/DP,pcm=3 (/dev/input/event10)
[    41.353] (II) No input driver specified, ignoring this device.
[    41.353] (II) This device may have been added with another device file.
[    41.353] (II) config/udev: Adding input device USB 2.0 PC Camera (/dev/input/event7)
[    41.353] (**) USB 2.0 PC Camera: Applying InputClass "evdev keyboard catchall"
[    41.353] (**) USB 2.0 PC Camera: Applying InputClass "system-setup-keyboard"
[    41.353] (II) Using input driver 'evdev' for 'USB 2.0 PC Camera'
[    41.353] (II) Loading /usr/lib/xorg/modules/input/evdev_drv.so
[    41.353] (**) USB 2.0 PC Camera: always reports core events
[    41.353] (**) evdev: USB 2.0 PC Camera: Device: "/dev/input/event7"
[    41.354] (--) evdev: USB 2.0 PC Camera: Vendor 0x1210 Product 0x25f4
[    41.354] (--) evdev: USB 2.0 PC Camera: Found keys
[    41.354] (II) evdev: USB 2.0 PC Camera: Configuring as keyboard
[    41.354] (**) Option "config_info" "udev:/sys/devices/pci0000:00/0000:00:13.2/usb2/2-3/2-3:1.0/input/input7/event7"
[    41.354] (II) XINPUT: Adding extended input device "USB 2.0 PC Camera" (type: KEYBOARD, id 10)
[    41.354] (**) Option "xkb_rules" "evdev"
[    41.354] (**) Option "xkb_model" "pc105+inet"
[    41.354] (**) Option "xkb_layout" "us"
[    41.354] (**) Option "xkb_options" "terminate:ctrl_alt_bksp,"
[    41.354] (II) config/udev: Adding input device HDA ATI SB Mic (/dev/input/event8)
[    41.354] (II) No input driver specified, ignoring this device.
[    41.354] (II) This device may have been added with another device file.
[    41.354] (II) config/udev: Adding input device HDA ATI SB Headphone (/dev/input/event9)
[    41.354] (II) No input driver specified, ignoring this device.
[    41.354] (II) This device may have been added with another device file.
[    41.355] (II) config/udev: Adding input device AT Translated Set 2 keyboard (/dev/input/event4)
[    41.355] (**) AT Translated Set 2 keyboard: Applying InputClass "evdev keyboard catchall"
[    41.355] (**) AT Translated Set 2 keyboard: Applying InputClass "system-setup-keyboard"
[    41.355] (II) Using input driver 'evdev' for 'AT Translated Set 2 keyboard'
[    41.355] (II) Loading /usr/lib/xorg/modules/input/evdev_drv.so
[    41.355] (**) AT Translated Set 2 keyboard: always reports core events
[    41.355] (**) evdev: AT Translated Set 2 keyboard: Device: "/dev/input/event4"
[    41.355] (--) evdev: AT Translated Set 2 keyboard: Vendor 0x1 Product 0x1
[    41.355] (--) evdev: AT Translated Set 2 keyboard: Found keys
[    41.355] (II) evdev: AT Translated Set 2 keyboard: Configuring as keyboard
[    41.355] (**) Option "config_info" "udev:/sys/devices/platform/i8042/serio0/input/input4/event4"
[    41.355] (II) XINPUT: Adding extended input device "AT Translated Set 2 keyboard" (type: KEYBOARD, id 11)
[    41.355] (**) Option "xkb_rules" "evdev"
[    41.355] (**) Option "xkb_model" "pc105+inet"
[    41.355] (**) Option "xkb_layout" "us"
[    41.355] (**) Option "xkb_options" "terminate:ctrl_alt_bksp,"
[    41.356] (II) config/udev: Adding input device SynPS/2 Synaptics TouchPad (/dev/input/event5)
[    41.356] (**) SynPS/2 Synaptics TouchPad: Applying InputClass "evdev touchpad catchall"
[    41.356] (**) SynPS/2 Synaptics TouchPad: Applying InputClass "touchpad catchall"
[    41.356] (II) LoadModule: "synaptics"
[    41.356] (II) Loading /usr/lib/xorg/modules/input/synaptics_drv.so
[    41.356] (II) Module synaptics: vendor="X.Org Foundation"
[    41.356]     compiled for 1.11.1, module version = 1.5.0
[    41.356]     Module class: X.Org XInput Driver
[    41.356]     ABI class: X.Org XInput driver, version 13.0
[    41.356] (II) Using input driver 'synaptics' for 'SynPS/2 Synaptics TouchPad'
[    41.356] (II) Loading /usr/lib/xorg/modules/input/synaptics_drv.so
[    41.356] (**) SynPS/2 Synaptics TouchPad: always reports core events
[    41.356] (**) Option "Device" "/dev/input/event5"
[    41.374] (--) synaptics: SynPS/2 Synaptics TouchPad: x-axis range 1472 - 5672
[    41.374] (--) synaptics: SynPS/2 Synaptics TouchPad: y-axis range 1408 - 4910
[    41.374] (--) synaptics: SynPS/2 Synaptics TouchPad: pressure range 0 - 255
[    41.374] (--) synaptics: SynPS/2 Synaptics TouchPad: finger width range 0 - 0
[    41.374] (--) synaptics: SynPS/2 Synaptics TouchPad: buttons: left right double triple
[    41.374] (--) synaptics: SynPS/2 Synaptics TouchPad: Vendor 0x2 Product 0x7
[    41.380] (--) synaptics: SynPS/2 Synaptics TouchPad: touchpad found
[    41.380] (**) SynPS/2 Synaptics TouchPad: always reports core events
[    41.387] (**) Option "config_info" "udev:/sys/devices/platform/i8042/serio1/input/input5/event5"
[    41.387] (II) XINPUT: Adding extended input device "SynPS/2 Synaptics TouchPad" (type: TOUCHPAD, id 12)
[    41.387] (**) synaptics: SynPS/2 Synaptics TouchPad: (accel) MinSpeed is now constant deceleration 2.5
[    41.387] (**) synaptics: SynPS/2 Synaptics TouchPad: MaxSpeed is now 1.75
[    41.387] (**) synaptics: SynPS/2 Synaptics TouchPad: AccelFactor is now 0.037
[    41.388] (**) SynPS/2 Synaptics TouchPad: (accel) keeping acceleration scheme 1
[    41.388] (**) SynPS/2 Synaptics TouchPad: (accel) acceleration profile 1
[    41.388] (**) SynPS/2 Synaptics TouchPad: (accel) acceleration factor: 2.000
[    41.388] (**) SynPS/2 Synaptics TouchPad: (accel) acceleration threshold: 4
[    41.388] (--) synaptics: SynPS/2 Synaptics TouchPad: touchpad found
[    41.388] (II) config/udev: Adding input device SynPS/2 Synaptics TouchPad (/dev/input/mouse0)
[    41.389] (II) No input driver specified, ignoring this device.
[    41.389] (II) This device may have been added with another device file.
[    41.404] (II) RADEON(0): EDID vendor "SEC", prod id 12869
[    41.404] (II) RADEON(0): Printing DDC gathered Modelines:
[    41.404] (II) RADEON(0): Modeline "1366x768"x0.0   70.44  1366 1414 1446 1486  768 770 775 790 -hsync -vsync (47.4 kHz)
[    43.159] (II) RADEON(0): EDID vendor "SEC", prod id 12869
[    43.159] (II) RADEON(0): Printing DDC gathered Modelines:
[    43.159] (II) RADEON(0): Modeline "1366x768"x0.0   70.44  1366 1414 1446 1486  768 770 775 790 -hsync -vsync (47.4 kHz)
[    43.268] (II) RADEON(0): EDID vendor "SEC", prod id 12869
[    43.268] (II) RADEON(0): Printing DDC gathered Modelines:
[    43.268] (II) RADEON(0): Modeline "1366x768"x0.0   70.44  1366 1414 1446 1486  768 770 775 790 -hsync -vsync (47.4 kHz)
[    43.323] (II) RADEON(0): EDID vendor "SEC", prod id 12869
[    43.323] (II) RADEON(0): Printing DDC gathered Modelines:
[    43.323] (II) RADEON(0): Modeline "1366x768"x0.0   70.44  1366 1414 1446 1486  768 770 775 790 -hsync -vsync (47.4 kHz)
[    43.353] (II) RADEON(0): EDID vendor "SEC", prod id 12869
[    43.353] (II) RADEON(0): Printing DDC gathered Modelines:
[    43.353] (II) RADEON(0): Modeline "1366x768"x0.0   70.44  1366 1414 1446 1486  768 770 775 790 -hsync -vsync (47.4 kHz)
[    43.380] (II) RADEON(0): EDID vendor "SEC", prod id 12869
[    43.380] (II) RADEON(0): Printing DDC gathered Modelines:
[    43.380] (II) RADEON(0): Modeline "1366x768"x0.0   70.44  1366 1414 1446 1486  768 770 775 790 -hsync -vsync (47.4 kHz)
[    53.302] (II) RADEON(0): EDID vendor "SEC", prod id 12869
[    53.303] (II) RADEON(0): Printing DDC gathered Modelines:
[    53.303] (II) RADEON(0): Modeline "1366x768"x0.0   70.44  1366 1414 1446 1486  768 770 775 790 -hsync -vsync (47.4 kHz)
[    53.337] (II) RADEON(0): EDID vendor "SEC", prod id 12869
[    53.337] (II) RADEON(0): Printing DDC gathered Modelines:
[    53.337] (II) RADEON(0): Modeline "1366x768"x0.0   70.44  1366 1414 1446 1486  768 770 775 790 -hsync -vsync (47.4 kHz)
[    53.391] (II) RADEON(0): EDID vendor "SEC", prod id 12869
[    53.391] (II) RADEON(0): Printing DDC gathered Modelines:
[    53.391] (II) RADEON(0): Modeline "1366x768"x0.0   70.44  1366 1414 1446 1486  768 770 775 790 -hsync -vsync (47.4 kHz)
[    53.426] (II) RADEON(0): EDID vendor "SEC", prod id 12869
[    53.427] (II) RADEON(0): Printing DDC gathered Modelines:
[    53.427] (II) RADEON(0): Modeline "1366x768"x0.0   70.44  1366 1414 1446 1486  768 770 775 790 -hsync -vsync (47.4 kHz)
[    53.451] (II) RADEON(0): EDID vendor "SEC", prod id 12869
[    53.451] (II) RADEON(0): Printing DDC gathered Modelines:
[    53.451] (II) RADEON(0): Modeline "1366x768"x0.0   70.44  1366 1414 1446 1486  768 770 775 790 -hsync -vsync (47.4 kHz)
[    55.774] (II) RADEON(0): EDID vendor "SEC", prod id 12869
[    55.774] (II) RADEON(0): Printing DDC gathered Modelines:
[    55.774] (II) RADEON(0): Modeline "1366x768"x0.0   70.44  1366 1414 1446 1486  768 770 775 790 -hsync -vsync (47.4 kHz)
[    56.977] (II) RADEON(0): EDID vendor "SEC", prod id 12869
[    58.039] (II) RADEON(0): Printing DDC gathered Modelines:
[    58.039] (II) RADEON(0): Modeline "1366x768"x0.0   70.44  1366 1414 1446 1486  768 770 775 790 -hsync -vsync (47.4 kHz)

Устанавливал драйвер по этой ссылке: http://support.amd.com/us/gpudownload/l … linux.aspx

До этого стояли драйвера AMD 8.x по моему, потому что если я не ошибаюсь когда устанавливал новые драйвера он написал, что-то вроде: "you install amd 12.2 later amd 8.x"

Новые драйвера устанавливал командой sh amd12.run (название .run файла было другое)

Результат команды lsmod:

Module                  Size  Used by
ppdev                  17363  0 
parport_pc             27442  0 
lp                     17486  0 
parport                39179  3 ppdev,parport_pc,lp
fuse                   71231  3 
be2iscsi               62864  0 
iscsi_boot_sysfs       15121  1 be2iscsi
bnx2i                  49424  0 
cnic                   57653  1 bnx2i
uio                    14374  1 cnic
cxgb4i                 32063  0 
cxgb4                  96268  1 cxgb4i
cxgb3i                 28014  0 
fcoe                   22673  0 
libcxgbi               50487  2 cxgb4i,cxgb3i
libfcoe                41950  1 fcoe
cxgb3                 130826  1 cxgb3i
mdio                   13214  1 cxgb3
ib_iser                32818  0 
rdma_cm                36864  1 ib_iser
libfc                 101889  2 fcoe,libfcoe
scsi_transport_fc      47165  2 fcoe,libfc
ib_cm                  36679  1 rdma_cm
scsi_tgt               18993  1 scsi_transport_fc
8021q                  23401  0 
garp                   13744  1 8021q
stp                    12719  1 garp
llc                    13770  2 garp,stp
iw_cm                  13715  1 rdma_cm
ib_sa                  23625  2 rdma_cm,ib_cm
ib_mad                 37189  2 ib_cm,ib_sa
ib_core                61900  6 ib_iser,rdma_cm,ib_cm,iw_cm,ib_sa,ib_mad
ib_addr                13473  1 rdma_cm
iscsi_tcp              18015  0 
libiscsi_tcp           19333  4 cxgb4i,cxgb3i,libcxgbi,iscsi_tcp
libiscsi               44809  8 be2iscsi,bnx2i,cxgb4i,cxgb3i,libcxgbi,ib_iser,iscsi_tcp,libiscsi_tcp
scsi_transport_iscsi    45361  8 be2iscsi,bnx2i,libcxgbi,ib_iser,iscsi_tcp,libiscsi
ip6t_REJECT            12782  2 
nf_conntrack_ipv6      13885  1 
nf_defrag_ipv6         13678  1 nf_conntrack_ipv6
nf_conntrack_ipv4      14182  1 
nf_defrag_ipv4         12601  1 nf_conntrack_ipv4
ip6table_filter        12711  1 
xt_state               12514  2 
nf_conntrack           70512  3 nf_conntrack_ipv6,nf_conntrack_ipv4,xt_state
ip6_tables             17844  1 ip6table_filter
snd_hda_codec_hdmi     31469  1 
snd_hda_codec_realtek   121580  1 
snd_hda_intel          32323  2 
snd_hda_codec         102795  3 snd_hda_codec_hdmi,snd_hda_codec_realtek,snd_hda_intel
snd_hwdep              13236  1 snd_hda_codec
snd_seq                54637  0 
snd_seq_device         13817  1 snd_seq
arc4                   12473  2 
snd_pcm                81170  3 snd_hda_codec_hdmi,snd_hda_intel,snd_hda_codec
ath9k                 120085  0 
mac80211              427444  1 ath9k
snd_timer              23896  2 snd_seq,snd_pcm
snd                    62853  13 snd_hda_codec_hdmi,snd_hda_codec_realtek,snd_hda_intel,snd_hda_codec,snd_hwdep,snd_seq,snd_seq_device,snd_pcm,snd_timer
soundcore              14116  1 snd
ath9k_common           13392  1 ath9k
ath9k_hw              389596  2 ath9k,ath9k_common
ath                    18561  3 ath9k,ath9k_common,ath9k_hw
cfg80211              169437  3 ath9k,mac80211,ath
uvcvideo               66834  0 
videobuf2_core         27177  1 uvcvideo
videodev               87311  2 uvcvideo,videobuf2_core
media                  19719  2 uvcvideo,videodev
videobuf2_vmalloc      12839  1 uvcvideo
videobuf2_memops       13086  1 videobuf2_vmalloc
snd_page_alloc         13709  2 snd_hda_intel,snd_pcm
rfkill                 20417  2 cfg80211
sp5100_tco             13417  0 
joydev                 17124  0 
microcode              18642  0 
video                  18500  0 
k10temp                12951  0 
i2c_piix4              13406  0 
sky2                   48959  0 
binfmt_misc            17207  1 
uinput                 17246  0 
radeon                750846  2 
ttm                    58465  1 radeon
drm_kms_helper         30903  1 radeon
drm                   199418  4 radeon,ttm,drm_kms_helper
i2c_algo_bit           12980  1 radeon
i2c_core               28151  6 videodev,i2c_piix4,radeon,drm_kms_helper,drm,i2c_algo_bit

5

Работу проприетарных драйверов ни кто не гарантирует. Так и сейчас этот драйвер несовместим с текущей версией Xorg. Удали его.
А во-вторых, компиза в гноме нет ведь уже.

6 (03.06.2012 10:11:05 отредактировано mr_zedox)

Vascom пишет:

Работу проприетарных драйверов ни кто не гарантирует. Так и сейчас этот драйвер несовместим с текущей версией Xorg. Удали его.
А во-вторых, компиза в гноме нет ведь уже.

1) Как удалить установленные драйвера?
2) Какие именно дрова надо удалить?
4) Как мне вернуть свой Gnome? А то у меня какая то дрянская старая тема!
3) Как нет compiz? А как же вязкие окна? ac

7

1. Ну там должен быть какой-то uninstall. Узнавай у драйвера, раз сумел поставить его.
2. Драйвер fglrx.
3. Верни нормальный открытый драйвер, который был до этого.
4. Теперь всё это в gnome-shell есть.

8

При всём уважении к вам, Vascom, но в gnome-shell вязких окон нет...

9

DarkDigger пишет:

При всём уважении к вам, Vascom, но в gnome-shell вязких окон нет...

мне кажется он это и не имел ввиду, он хотел сказать, что все граф. эффекты перешли в gnome-shell

10

Vascom пишет:

1. Ну там должен быть какой-то uninstall. Узнавай у драйвера, раз сумел поставить его.
2. Драйвер fglrx.
3. Верни нормальный открытый драйвер, который был до этого.
4. Теперь всё это в gnome-shell есть.

Есть задачи:
1) Удалить тот драйвер который я сейчас установил (по твоим словам это "fglrx")
2) Инстальнуть те драйвера которые ты скажешь ab
3) Забить на compiz
4) Добавить тебя в аське

11

Vascom пишет:

Ну там должен быть какой-то uninstall. Узнавай у драйвера, раз сумел поставить его

Это можно узнать, просмотрев лог установки, посмотрите в /var/log, там должен быть файлик *.log, относящийся к ati. У меня nvidia, поэтому точно сказать не могу.

Истинный hotplug - это обычная электрическая розетка: воткнул - работает, и никаких драйверов.
Arch Linux/Xfce/Xiaomi Mi Notebook Pro 15.6 | Slackware64-current/Xfce/Lenovo G580

12

yars пишет:
Vascom пишет:

Ну там должен быть какой-то uninstall. Узнавай у драйвера, раз сумел поставить его

Это можно узнать, просмотрев лог установки, посмотрите в /var/log, там должен быть файлик *.log, относящийся к ati. У меня nvidia, поэтому точно сказать не могу.

там их больше пяти:
http://s019.radikal.ru/i642/1206/e0/b550c8239f7d.jpg

13

mr_zedox пишет:

там их больше пяти:

Ок, а этот файл есть?
/usr/share/ati/fglrx-install.log

Истинный hotplug - это обычная электрическая розетка: воткнул - работает, и никаких драйверов.
Arch Linux/Xfce/Xiaomi Mi Notebook Pro 15.6 | Slackware64-current/Xfce/Lenovo G580

14

mr_zedox пишет:

3) Как нет compiz? А как же вязкие окна? sad

с гномошелью он не работает, можешь забыть навсегда.

" si contuderis stultum in pila quasi tisanas feriente desuper pilo non auferetur ab eo stultitia eius " © Proverbs 27:22

15

yars пишет:
mr_zedox пишет:

там их больше пяти:

Ок, а этот файл есть?
/usr/share/ati/fglrx-install.log

Есть но не открывается у меня не одна программа после краха дров, вот этот файл: http://zalil.ru/33375611

16

помогите ac

17

Uninstalling any previously installed drivers.

перевод : "удалите ранее установленные драйвера"
другими словами у тебя драйвер не установился вообще . Решить это можно через переустановку тех драйверов которые уже есть в системе, смотри через гуй что стоит и тупо переустанови.

" si contuderis stultum in pila quasi tisanas feriente desuper pilo non auferetur ab eo stultitia eius " © Proverbs 27:22

18

gramozeka пишет:

Uninstalling any previously installed drivers.

перевод : "удалите ранее установленные драйвера"
другими словами у тебя драйвер не установился вообще . Решить это можно через переустановку тех драйверов которые уже есть в системе, смотри через гуй что стоит и тупо переустанови.

Команду сделал, что устанавливать теперь?

19

Могу посоветовать:
yum update
yum install kmod-catalyst xorg-x11-drv-catalyst xorg-x11-drv-catalyst-libs.i686

20

DarkDigger пишет:

Могу посоветовать:
yum update
yum install kmod-catalyst xorg-x11-drv-catalyst xorg-x11-drv-catalyst-libs.i686

Загружены модули: langpacks, presto, refresh-packagekit
Пакета с названием kmod-catalyst не найдено.
Пакета с названием xorg-x11-drv-catalyst не найдено.
Пакета с названием xorg-x11-drv-catalyst-libs.i686 не найдено.
Ошибка: Выполнять нечего

21

почитай здесь:
http://forums.fedoraforum.org/showthread.php?t=155503

22

DarkDigger пишет:

почитай здесь:
http://forums.fedoraforum.org/showthread.php?t=155503

Не устанавливает он по той инструкции ac

23

И не установится он. Я же написал: "Так и сейчас этот драйвер несовместим с текущей версией Xorg."

24

Верни открытый драйвер...
https://www.linux.org.ru/forum/general/6815090

25

Vascom пишет:

И не установится он. Я же написал: "Так и сейчас этот драйвер несовместим с текущей версией Xorg."

И как теперь быть? КАк вернуть gnome нормальный? xorg.conf у меня почему то удалился, его нет в X11 папке.

26

Ну и хорошо, xorg.conf и не должно быть.
Гугли как удалить твой драйвер, этой информации полно в интернете.

27

Vascom пишет:

Ну и хорошо, xorg.conf и не должно быть.
Гугли как удалить твой драйвер, этой информации полно в интернете.

А какой именно удалять он же не один?
Может нужно всю ATI папку удалить и заново установить?
Вот, что выводит "aticonfig":

        specialized monitor equipment is required.
  --resolution=Screen#,W1xH1,W2xH2,W3xH3,...
        Set the modes for the specified screen.  You may specify several
        resolutions separated by commas.
        Screens start at 0.  You can use 1 for dual-head
  --hsync=Screen#,LOW-HIGH
        Change the horizontal sync range of the specified monitor.  Make sure
        you know the capabilities of your monitor before changing this option.
        Screens start at 0.  You can use 1 for dual-head
  --vrefresh=Screen#,LOW-HIGH
        Change the vertical refresh range of the specified monitor.  Make sure
        you know the capabilities of your monitor before changing this option.
        Screens start at 0.  You can use 1 for dual-head
  --hsync2=LOW-HIGH
        Change the horizontal sync range of the second display.  Make sure you
        know the capabilities of your monitor before changing this option.
  --vrefresh2=LOW-HIGH
        Change the vertical refresh range of the second display.  Make sure you
        know the capabilities of your monitor before changing this option.
  --mode2=W1xH1,W2XH2,W3xH3,...
        Change the modes for the second display.  You may specify several
        resolutions separated by commas.  Only valid for clone and big desktop
        settings.
  --screen-layout={left|right|above|below}
        Set the secondary screen position for dual head.
  --screen-overlap=NUM
        Set the screen overlap region in big desktop mode to be NUM pixels.
Advanced Options:
  --sync-video={on|off}
        Enable/disable sync to vsync for AVIVO video.
        This option is enabled by default and is used to prevent
        video tearing. By disabling this option video is free to
        render as fast as the 3D engine can handle. In the case of
        choppy video try to disable sync-video.
  --tls={on|off}
        Enable/disable fast thread local storage.  Disable this option when
        virtual machines or WineX fail to work properly.
  --locked-userpages={on|off}
        Enable/disable locked user pages. Disable this option if the system
        hangs when running fgl_glxgears.
        User page lock is no longer available on AGP system now.
  --max-gart-size=VALUE1,VALUE2
        Set user-defined max total GART size(VALUE1) and cacheable gart
        size(VALUE2) for non-AGP systems.
        This option can combined with --adapter option to set the gart size
        for individual card. 

Dynamic Display Management Options:
  Following options will not change the config file. They are
  used for querying driver, controller and adaptor information.
  These options will be effective immediately. Other options on 
  the same command line will be ignored.
  --enable-monitor=STRING,STRING
        Setting current monitor to be enabled. Only 2 displays
        can be enabled at the same time. Any displays
        that are not on the list will be disabled.
        STRING can be one of the following set, separated 
        by commas:
            none
            crt1
            crt2
            lvds
            tv
            cv
            tmds1
            tmds2
            tmds2i
            dfp3
            dfp4
            dfp5
            dfp6
            auto   -- use default policy to enable the displays.
  --query-monitor
        This will return connected and enabled monitor information
  --swap-monitor
        This only works for big desktop setup. This will swap the
        contents on the two monitors.
  --swap-screens={on|off}
        Enable/disable swap heads in dual-head mode.
        This option works only in dual-head mode.

Pair mode options: 
  Following options are used for query add and remove pair modes. 
  These options will be effective immediately. Other options on   
  the same command line will be ignored.
  --list-pairmode 
        list all the current existing pair modes the driver can use.
  --add-pairmode=width0xheight0+width1xheight1
        Add one pair mode to the list. width0 and height0 are the 
        size of primary display and width1 and height1 for the 
        secondary  display.
  --remove-pairmode=index 
        Remove one pair mode from the list. User can get index by 
        list-pairmode.

External Events Daemon Options:
  Following options will not change the config file. They are
  used to send commands to the atieventsd external events daemon.
  --set-policy=STRING
        Sets the event policy for the daemon to be STRING.
        See the atieventsd(8) manpage for further details.

Display attribute options:
  Following options are used for query and set adjustment of 
  specific attribute for specific display. These options will be 
  effective immediately. Other options on the same command line 
  will be ignored.
  The DISPLAYTYPE in options can be one of the following strings:
        crt1,  lvds,   tv,   cv,   tmds1, crt2,
        tmds2, tmds2i, dfp3, dfp4, dfp5,  dfp6 .
   The ATTRIBTYPE in options can be one of the following strings:
        brightness, contrast, saturation, hue, positionX, 
        positionY, sizeX, sizeY, overscan, videoStandard  
  --query-dispattrib=DISPLAYTYPE,ATTRIBTYPE 
        query the specific adjustment info of the specific display.
        if ATTRIBTYPE is not specified, all supported attribute 
        information will be printed out. 
  --set-dispattrib=DISPLAYTYPE,ATTRIBTYPE:VALUE 
        set the attribute value of the specific display.

Connector type options:
  Following options are used for query connector type 
  for specific display. These options will be 
  effective immediately. Other options on the same command line 
  will be ignored.
  The DISPLAYTYPE in options can be one of the following strings:
        crt1,  lvds,   tv,   cv,   tmds1, crt2,
        tmds2, tmds2i, dfp3, dfp4, dfp5,  dfp6 .
   --query-connectortype=DISPLAYTYPE 
        query the connector type of the specific display.

Component video dongle options:
  Following options are used for query and set dongles for a 
  component video. These options will be effective immediately.
  Other options on the same command line will be ignored.
  --query-cvdongle
        query dongle setting informations of the component video.
  --set-cvdongle=VALUE
        set the custom override value of the CV dongle. 
  --reset-cvdongle
        reset the custom override setting(to zero)of the CV dongle.

Component video customized mode options:
  Following options are used for query and set customized mode for
  component video. These options will be effective immediately.
  Other options on the same command line will be ignored.
  --query-cvmode
        query customized modes for component video.
  --add-cvmode=WIDTH,HEIGHT,FLAGS,BASEWIDTH,BASEDHEIGHT,REFRESH.
        add a customized mode for component video.
  --validate-cvmode=WIDTH,HEIGHT,FLAGS,BASEWIDTH,BASEHEIGHT,REFRESH.
        validate a customized mode for component video.
  --delete-cvmode=INDEX 
        delete one customized mode for component video. 

Persistent Configuration Store (PCS) Options:
  Following options will not change the config file. They are
  used to manipulate the PCS database.  Due to their nature, these.
  commands may only be run by the root user. Note that the prefix
  and key names are not case-sensitive.
  --get-pcs-key=PREFIX,KEY
        Prints out the specified prefix and key from the PCS
        database.  The type of data will be shown along with
        the contents.
  --set-pcs-u32=PREFIX,KEY,VALUE
  --set-pcs-val=PREFIX,KEY,VALUE (deprecated)
        Sets an integer value at the specified prefix and key in
        the PCS database.  The value may be specified in hex by
        prefixing it with 0x or in octal by prefixing it with 0,
        otherwise the value is assumed to be in decimal.  Note
        that --set-pcs-val is deprecated and --set-pcs-u32 should
        be used instead.  --set-pcs-val will be removed soon.
  --set-pcs-u32array=PREFIX,KEY,VALUE[,VALUE]...
        Sets an array of integer values at the specified prefix
        and key in the PCS database.  The values may be specified
        in hex by prefixing it with 0x or in octal by prefixing
        it with 0, otherwise the value is assumed to be in decimal.
        (e.g. --set-pcs-u32array="TestSection,TestData,1,0x2,3")
  --set-pcs-str=PREFIX,KEY,STRING
        Sets a string value at the specified prefix and key in
        the PCS database.
  --set-pcs-raw=PREFIX,KEY,HEXSTRING
        Sets a raw binary value at the specified prefix and key in
        the PCS database.  The value is specified as a series of
        hex bytes with no 0x or spaces.
        (e.g. --set-pcs-raw="TestSection,TestData,E84C0E" sets 3 bytes)
  --set-pcs-bool=PREFIX,KEY,VALUE
        Sets a boolean value at the specified prefix and key in
        the PCS database.  The value may be specified as either
        "true", "yes", "on", "enable" or "1" meaning boolean TRUE or
        "false", "no", "off", "disable" or "0" meaning boolean FALSE.
  --del-pcs-key=PREFIX,KEY
        Deletes the specified prefix and key from the PCS database.

Multiple display adapter options:
  Following options are used for querying and setting up multiple
  display adapters that are installed for multihead or Crossfire
  configurations.
  --lsa, --list-adapters
        Lists all detected and supported display adapters.
        The default adapter (used when --adapter is not specified)
        will be indicated with a "*" next to it.
  --adapter=ADAPTERLIST
        Selects which adapters returned by --list-adapters should
        be affected by other aticonfig options.  ADAPTERLIST contains
        either a comma-seperated sequence of the index numbers of the
        adapters to be affected or else contains the keyword "all" to
        select all the adapters.  If --adapter is missing, only the
        default adapter will be affected.
  --lscc, --list-crossfire-candidates
        Queries the driver to determine the pool of available devices that can
        can be chained together for CrossFire.
  --lscs, --list-crossfire-status
        List current Crossfire status (enabled or disabled) along with diagnostics
        information indicates the status of your system
  --lsch, --list-crossfire-chains
        Lists the CrossFire chains that are currently defined along with their
        enabled state
  --cfa, --add-crossfire-chain
        Defines a new CrossFire chain.  --adapter should contain the adapter
        chain definition, with the master adapter being the first entry and
        the slave adapters being the subsequent entries in order of priority.
  --cfd, --delete-crossfire-chain
        Delete and existing defined CrossFire chain.  --adapter should list the
        master adapters of the chains to be deleted.  --adapter=all will delete
        all chain definitions.
  --cf, --crossfire={on|off}
        Enables/disables CrossFire support on the currently defined CrossFire
        chains.  --adapter should list the master adapters to be enabled or
        disabled.
  --cfl, --crossfire-logo={on|off}
        Enables/disables the appearance of the CrossFire Logo when rendering
        in CrossFire mode

AMD Overdrive (TM) options:
  The following options are used to get and set current and peak, core
  and memory clock information as well as read the current temperature of
  adapters.  By using the "--adapter=" argument the AMD Overdrive (TM)
  options can be targeted to a particular adapter in a multi-adapter scenario.
  If no adapter is explicitly targeted the commands will be run on the Default
  adapter as indicated by the "--list-adapters" command
  --od-enable
        Unlocks the ability to change core or memory clock values by
        acknowledging that you have read and understood the AMD Overdrive (TM)
        disclaimer and accept responsibility for and recognize the potential
        dangers posed to your hardware by changing the default core or memory
        clocks
  --od-disable
        Disables AMD Overdrive(TM) set related aticonfig options.  Previously
        commited core and memory clock values will remain, but will not be set
        on X Server restart.
  --odgc, --od-getclocks
        Lists various information regarding current core and memory clock
        settings.
        Including: current and peak clocks
                   the theoretical range clocks can be set to
                   the current load on the GPU
  --odsc, --od-setclocks={NewCoreClock|0,NewMemoryClock|0}
        Sets the core and memory clock to the values specified in MHz
        The new clock values must be within the theoretical ranges provided
        by --od-getclocks.  If a 0 is passed as either the NewCoreClock or
        NewMemoryClock it will retain the previous value and not be changed.
        There is no guarantee that the attempted clock values will succeed
        even if they lay inside the theoretical range.  These newly set
        clock values will revert to the default values if they are not
        committed using the "--od-commitclocks" command before X is
        restarted
  --odrd, --od-restoredefaultclocks
        Sets the core and memory clock to the default values.
        Warning X needs to be restarted before these clock changes will take
        effect
  --odcc, --od-commitclocks
        Once the stability of a new set of custom clocks has been proven this
        command will ensure that the Adapter will attempt to run at these new
        values whenever X is restarted
  --odgt, --od-gettemperature
        Returns the temperature reported by any thermal sensors available on
        the adapter.

ACPI Options:
  --acpi-services=on|off
        Enable/disable ACPI services. In the case of BIOS or kernel ACPI issues,
        ACPI services in the driver can be disabled through this option.
        The ACPI services are enabled by default.
  --acpi-display-switch=on|off
        Enable/disable display switching with ACPI methods on mobile platforms.
        This option is enabled by default.

Genlock/Framelock options:
  The following options are used to control operation with GLSYNC module
  in the system.  By using the "--adapter=" argument --glsync-getconfig,
  --glsync-setconfig, --glsync-getgenlock, --glsync-setgenlock options
  can be targeted to a particular adapter in a multi-adapter scenario.
  If no adapter is explicitly targeted the commands will be run on the Default
  adapter as indicated by the "--list-adapters" command
  --glsync-getport={RJ45_1 | RJ45_2 | BNC}
        Get configuration state for specified GLSync port.
        Including: Number of LEDs
                   Scanned frequency
                   Signal Source for RJ45 port if it is configured as output 
                   Port state (Input or Output) for RJ45 port
                   Signal type for BNC port
  --glsync-setport=port_type,cntl,sig_src
        Set configuration for specified GLSync port
        Parameters: port_type - RJ45_1 or RJ45_2
                                only RJ45 ports can be configured
                    cntl - 0 if port is configured as input or
                           1 if port is configured as output
                    sig_src - signal source for GL Sync port
                              if 0-3 - GPU port index
                              if RJ45_1, RJ45_2 or BNC - another GL Sync port
                              if -1  - signal source is undefined
  --glsync-getconfig
        Get timing configuration for particular GL Sync connector
        Including: Sync Delay in ms
                   Signal Source
                   Sample Rate
                   Sync field
                   Trigger Edge
                   Scan Rate multiplier
                   GPU port index this adapter connected to
  --glsync-setconfig=delay,fr_cntl,sig_src,smpl_rate,fld,edge,coef
        Set timing configuration for GL Sync connector
        Parameters: delay - Sync Delay in ms
                    fr_cntl - Enable/Disable framlock control 
                              0 Disable Framelock
                              1 Enable Framelock
                    sig_src - Signal Source for this adapter.
                              if 0-3 - GPU port index.
                                   It can not be GPU port index of this adapter
                              if RJ45_1, RJ45_2 or BNC - GL Sync port
                              if -1  - signal source is undefined
                    smpl_rate - Sample Rate for sampled sync signal.
                              0 for no sampling
                    fld - Sync field for interlaced sync signal. 
                              0 if sync field is undefined
                              1 if synced to both field
                              2 if synced to field 1
                    edge - it is defined which signal edge
                                 should trigger synchronization
                              0 if edge is undefined
                              1 if it is triggered by raising edge
                              2 if it is triggered by falling edge
                              3 if it is triggered by both edges
                    coef - Scan Rate multiplier applied to sync signal
                              0 if coef is undefined
                              1 if coef is 5
                              2 if coef is 4
                              3 if coef is 3
                              4 if coef is 2.5
                              5 if coef is 2
                              6 if coef is 1.33
                              7 if coef is 1.25
                              8 if coef is 1.
                              9 if coef is 0.8
                             10 if coef is 0.67
                             11 if coef is 0,5
                             12 if coef is 0.4
                             13 if coef is 0.33
                             14 if coef is 0.25
                             15 if coef is 0.2
        Note: Some parameters may not be valid for manual configuration.
              Please use --glsync-getconfig command to verify.
  --glsync-getgenlock=disp_type
        Get genlock mode for particular display
        disp_type  - Display Type. When RandR 1.2 and above is enabled
                     can be query by using xrandr -q command.
                     If RandR 1.2 is not enabled
                     aticonfig --query-monitor command should be used
                     to query this parameter
  --glsync-setgenlock=disp_type,mode,timing_server
        Set genlock mode for particular display
        Parameters: disp_type  - Display Type.
                                 When RandR 1.2 and above is enabled
                                 can be query by using xrandr -q command.
                                 If RandR 1.2 is not enabled
                                 aticonfig --query-monitor command
                                 should be used to query this parameter.
                    mode       - Enable/Disable Genlock
                                 0 Disable Genlock
                                 1 Enable Genlock
                    timing_server - Enable/Disable timing server
                                 0 to configure display as free run
                                 1 to configure display as a timing server
  --glsync-restart
        Reinitialized all genlock settings after power down system

X Server Options:
  --xinerama={on|off}
        Enable/disable Xinerama (MultiView) in the X Server configuration file.
        MultiView allows for the merging of independent desktop heads into a
        unified workspace allowing windows to freely cross X Screen boundaries.

Uninstall options:
     --uninstall{=force|dryrun}
         dryrun tests uninstall but does not uninstall.
         force removes all installed files without verification. 
         Uninstall without an option tries to perform the default uninstall procedure.

Miscellaneous Options:
  -v, --verbose
        Show what aticonfig is doing.
  -q, --quiet
        Disable all information output except for errors.
  --effective={now,startup}
        Choose when the requested changes should take effect.
            now:     Immediately.  This change will affect the running X
                     session if applicable.  Only 'set-powerstate' and
                     'overlay-on' are applicable for now.
            startup: On future X server startups.  This change will modify the
                     X server configuration file if applicable.
        The default is 'now,startup', i.e., do both as applicable.
  --nobackup
        Do not make an automatic backup of the configuration file.
  -i, --input=FILE
        Select a FILE to input as the configuration file. Set FILE to '-' to
        pipe from standard input.  Without this option, aticonfig will search
        /etc/X11 for the default configuration file.
  -o, --output=FILE
        Select a FILE to output the new configuration file to.  Set FILE to '-'
        to print to standard output.  Without this option, aticonfig will
        replace the input file with the newly generated file.
  -h, --help
        Display this help screen.
  -f, --force
        Only valid with 'initial' option.  Force aticonfig to generate default
        Monitor, Device, and Screen sections even if the original configuration
        file has invalid settings in these sections.

Composite options:
  --xv-pixmap-buffer-type=gartcacheable
       Allocate pixmap buffer from GART cacheable heap.
  --xv-pixmap-buffer-type=lfb
       Allocate pixmap buffer from local framebuffer.
  --xv-pixmap-buffer-type=gartuswc
       Allocate pixmap buffer from GART USWC heap.

PowerXpress options:
  --px-list-active-gpu
  --pxl
       List current activated GPU
  --px-dgpu
       Activate discrete GPU (High-Performance mode), must re-start X to take effect
  --px-igpu
       Activate integrated GPU (Power-Saving mode), must re-start X to take effect

Examples:
  1. Setting up fglrx for the first time.
       Single head :    aticonfig --initial --input=/etc/X11/xorg.conf
       Dual head   :    aticonfig --initial=dual-head --screen-layout=above
                        This command will generate a dual head configuration
                        file with the second screen located above the first
                        screen.
       Multi head  :    aticonfig --initial --heads=4 --adapter=1
                        This command will generate 4 adjacent X Screens
                        on adapter 1.  Use with -f to reduce previously configured heads.
  2. Setting up big desktop to horizontal and set overlay on secondary display.
                        aticonfig --dtop=horizontal --overlay-on=1
  3. Setting up modes for primary display.
                        aticonfig --resolution=0,1600x1200,1280x1024,1024x768
  4. Change tv geometry 
                         aticonfig --tv-geometry=85x90+10-10 
         This will set tv to 85% width (where 100% ==
         overscan) 90% height and shift 10 pixels right of centre
         and 10 pixels down of centre. 
  5. Multiple display adapters.
       List adapters :  aticonfig --list-adapters
       Init 0 and 2  :  aticonfig --adapter=0,2 --initial
       Init all      :  aticonfig --adapter=all --initial
       MultiView     :  aticonfig --xinerama=on
  6. AMD Overdrive (TM).
       List adapters          :  aticonfig --list-adapters
       Get Clocks of 0        :  aticonfig --adapter=0 --od-getclocks
       Set new Clocks for 0   :  aticonfig --adapter=0 --od-setclocks=770,1126
       Test out 3D            :  atiode -P60 -H localhost:0; echo $?
       Check Temperature of 0 :  aticonfig --adapter=0 --od-gettemperature
       Commit changes for 0   :  aticonfig --adapter=0 --od-commitclocks

     ***note***
             atiode is a stress application you start with a required
             parameter -P which specifies the test duration and the optional
             -H parameter to target a specific display to use.  For example
             atiode -P 600 -H localhost:0 would test display 0 for 10 minutes
             the return code from the application is the test result
             0: Test successfully completed.
             1: Invalid command-line parameters.
             2: Test failed because of rendering errors.
             3: Target adapter not found.
             4: Test aborted due to unknown reason

  7. Framelock/Genlock with GL Sync module
       Set GL Sync connector parameters for particular adapter: 
                     aticonfig --glsync-setconfig=0,0,2,0.0,3,8 --adapter=1
       Enable Genlock for particular display:
                     aticonfig --glsync-setgenlock=lvds,1,0 --adapter=1
       Enable Timing Master:
                     aticonfig --glsync-setgenlock=dfp3,0,1 --adapter=1
       Verify if the frequency is locked for particular display:
                     aticonfig --glsync-getgenlock=crt1 --adapter=1
       Set GL Sync output port RJ45_1:
                     aticonfig --glsync-setport=RJ45_1,1,BNC
       Reinitialize all genlock settings for all displays and adapters:
                     aticonfig --glsync-restart

Please report bugs to http://support.amd.com

28

Учись искать информацию самостоятельно.
Запусти /usr/share/fglrx/fglrx-uninstall.sh

29

Vascom пишет:

Учись искать информацию самостоятельно.
Запусти /usr/share/fglrx/fglrx-uninstall.sh

У меня нет такого файла, Vascom ac Ну пока не мере в папке Share точно...

30

поищи где-нибудь в другом месте
find / -name fglrx-uninstall.sh
Вроде так